intelmq.bots.experts.lookyloo package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.lookyloo package

## Submodules

## intelmq.bots.experts.lookyloo.expert module

intelmq.bots.experts.lookyloo.expert.BOT

  alias of `intelmq.bots.experts.lookyloo.expert.LookyLooExpertBot`

class intelmq.bots.experts.lookyloo.expert.LookyLooExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  LookyLoo expert bot for automated website screenshots

  init()
  instance_url: str = 'http://localhost:5100/'
  process()

## Module contents